@@ -3,17 +3,8 @@
  **
  **  Copyright 2007 Brian Aker brian@tangent.org
  **  
- **  Licensed under the Apache License, Version 2.0 (the "License");
- **  you may not use this file except in compliance with the License.
- **  You may obtain a copy of the License at
+ ** Please see "LICENSE" file that was included in the distribution.
  **  
- **  http://www.apache.org/licenses/LICENSE-2.0
- **  
- **  Unless required by applicable law or agreed to in writing, software
- **  distributed under the License is distributed on an "AS IS" BASIS,
- **  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- **  See the License for the specific language governing permissions and
- **  limitations under the License.
 */
 
 #include "mod_layout.h"
@@ -23,55 +14,27 @@ module AP_MODULE_DECLARE_DATA layout_module;
 static void
 set_config_defaults(apr_pool_t *p, layout_conf *cfg)
 {
-  bzero(cfg, sizeof(layout_conf));
-  cfg->replace_tags= UNSET;
-  cfg->merge= UNSET;
+  memset(cfg, 0, sizeof(layout_conf));
   cfg->notes= UNSET;
-  cfg->proxy= UNSET;
   cfg->comment= UNSET;
   cfg->append_header= UNSET;
   cfg->append_footer= UNSET;
-  cfg->cache_needed= UNSET;
   cfg->display_origin= ON;
   cfg->header_enabled= UNSET;
   cfg->footer_enabled= UNSET;
-  cfg->pattern_enabled= UNSET;
-  cfg->http_header_enabled= UNSET;
-  cfg->async_cache= LAYOUT_CACHE;
   cfg->begin_tag= LAYOUT_BEGINTAG;
   cfg->end_tag= LAYOUT_ENDTAG;
-  cfg->async_post= OFF;
   cfg->time_format= LAYOUT_TIMEFORMAT;
-  cfg->types= apr_table_make(p, 9); /* Doing default types was probably a bad idea */
-  cfg->layout_html_handler= ON;
 }
 
 static void *create_dir_mconfig(apr_pool_t *p, char *dir) 
 {
-  /* So why -1, 0, and 1?  You see, C lacks an arithmatic if. We need to
-    know three states at any point. We need to know if something is unset, off or
-    on. Hence we use these values. Apache already understands Off as 0 and 1 as
-    on. 
-  */
   layout_conf *cfg;
 
   cfg= apr_pcalloc(p, sizeof(layout_conf));
   set_config_defaults(p, cfg);
   cfg->dir= apr_pstrdup(p, dir);
 
-
-  apr_table_setn(cfg->types, INCLUDES_MAGIC_TYPE, "1");
-  apr_table_setn(cfg->types, INCLUDES_MAGIC_TYPE3, "1");
-  apr_table_setn(cfg->types, "server-parsed", "1");
-  apr_table_setn(cfg->types, "text/html", "1");
-  apr_table_setn(cfg->types, "text/plain", "1");
-  apr_table_setn(cfg->types, "perl-script", "1");
-  apr_table_setn(cfg->types, "cgi-script", "1");
-  apr_table_setn(cfg->types, "application/x-httpd-cgi", "1");
-  apr_table_setn(cfg->types, "application/x-httpd-php", "1");
-  apr_table_setn(cfg->types, "LayoutHandler application/x-httpd-php3", "1");
-  apr_table_setn(cfg->types, "LayoutHandler application/x-httpd-php3-source", "1");
-
   return (void *) cfg;
 }
 
@@ -83,157 +46,129 @@ static void *merge_dir_mconfig(apr_pool_t *p, void *origin, void *new)
   layout_conf *cfg_new= (layout_conf *)new;
   cfg->dir= apr_pstrdup(p, cfg_new->dir);
 
-  if (strcmp(cfg_new->async_cache, LAYOUT_CACHE)){
-    cfg->async_cache= apr_pstrdup(p, cfg_new->async_cache);
-  } else if (strcmp(cfg_origin->async_cache, LAYOUT_CACHE)){
-    cfg->async_cache= apr_pstrdup(p, cfg_origin->async_cache);
-  }
-
-  if (strcmp(cfg_new->time_format, LAYOUT_TIMEFORMAT)){
+  if (strcmp(cfg_new->time_format, LAYOUT_TIMEFORMAT))
     cfg->time_format= apr_pstrdup(p, cfg_new->time_format);
-  } else if (strcmp(cfg_origin->time_format, LAYOUT_TIMEFORMAT)){
+  else if (strcmp(cfg_origin->time_format, LAYOUT_TIMEFORMAT))
     cfg->time_format= apr_pstrdup(p, cfg_origin->time_format);
-  }
 
-  if (strcmp(cfg_new->begin_tag, LAYOUT_BEGINTAG)){
+  if (strcmp(cfg_new->begin_tag, LAYOUT_BEGINTAG))
     cfg->begin_tag= apr_pstrdup(p, cfg_new->begin_tag);
-  } else if (strcmp(cfg_origin->begin_tag, LAYOUT_BEGINTAG)){
+  else if (strcmp(cfg_origin->begin_tag, LAYOUT_BEGINTAG))
     cfg->begin_tag= apr_pstrdup(p, cfg_origin->begin_tag);
-  }
 
-  if (strcmp(cfg_new->end_tag, LAYOUT_ENDTAG)){
+  if (strcmp(cfg_new->end_tag, LAYOUT_ENDTAG))
     cfg->end_tag= apr_pstrdup(p, cfg_new->end_tag);
-  } else if (strcmp(cfg_origin->end_tag, LAYOUT_ENDTAG)){
+  else if (strcmp(cfg_origin->end_tag, LAYOUT_ENDTAG))
     cfg->end_tag= apr_pstrdup(p, cfg_origin->end_tag);
-  }
 
-  cfg->layout_html_handler= (cfg_new->layout_html_handler == OFF) ? OFF : cfg_origin->layout_html_handler;
-  cfg->cache_needed= (cfg_new->cache_needed == UNSET) ? cfg_origin->cache_needed : cfg_new->cache_needed;
-  cfg->proxy= (cfg_new->proxy == UNSET) ? cfg_origin->proxy : cfg_new->proxy;
-  cfg->merge= (cfg_new->merge == UNSET) ? cfg_origin->merge : cfg_new->merge;
   cfg->notes= (cfg_new->notes == UNSET) ? cfg_origin->notes : cfg_new->notes;
-  cfg->replace_tags= (cfg_new->replace_tags == UNSET) ? cfg_origin->replace_tags : cfg_new->replace_tags;
   cfg->comment= (cfg_new->comment == UNSET) ? cfg_origin->comment : cfg_new->comment;
-  cfg->async_post= (cfg_new->async_post == UNSET) ? cfg_origin->async_post : cfg_new->async_post;
   cfg->display_origin= cfg_new->display_origin;
 
   cfg->append_header= (cfg_new->append_header == UNSET) ? cfg_origin->append_header : cfg_new->append_header;
   cfg->append_footer= (cfg_new->append_footer == UNSET) ? cfg_origin->append_footer : cfg_new->append_footer;
 
-  if (isOn(cfg->append_header) || isOn(cfg->append_footer))  {
-    if (isOn(cfg->append_header) && isOn(cfg->append_footer))  {
+  if (isOn(cfg->append_header) || isOn(cfg->append_footer))
+  {
+    if (isOn(cfg->append_header) && isOn(cfg->append_footer))
+    {
       if (cfg_origin->layouts)
         cfg->layouts= apr_array_append(p, cfg_origin->layouts, cfg_new->layouts);
       else
         cfg->layouts= cfg_new->layouts;
+
       cfg->header_enabled= cfg_new->header_enabled ? cfg_new->header_enabled : cfg_origin->header_enabled;
       cfg->footer_enabled= cfg_new->footer_enabled ? cfg_new->footer_enabled : cfg_origin->header_enabled;
-    } else if (isOn(cfg->append_header)) {
+    } 
+    else if (isOn(cfg->append_header)) 
+    {
       cfg->header_enabled= cfg_new->header_enabled ? cfg_new->header_enabled : cfg_origin->header_enabled;
       cfg->footer_enabled= cfg_new->footer_enabled;
       cfg->layouts= layout_array_push_kind(p, cfg_origin->layouts, cfg_new->layouts, HEADER);
       /* We now assume just append_footer */
-    } else  {
+    } 
+    else  
+    {
       cfg->header_enabled= cfg_new->header_enabled;
       cfg->footer_enabled= cfg_new->footer_enabled ? cfg_new->footer_enabled : cfg_origin->header_enabled;
       cfg->layouts= layout_array_push_kind(p, cfg_origin->layouts, cfg_new->layouts, FOOTER);
     }
-  } else {
-    if (cfg_new->layouts){
+  } 
+  else 
+  {
+    if (cfg_new->layouts)
+    {
       cfg->layouts= cfg_new->layouts;
       cfg->header_enabled= cfg_new->header_enabled;
       cfg->footer_enabled= cfg_new->footer_enabled;
-      cfg->pattern_enabled= cfg_new->pattern_enabled;
-    } else {
+    } 
+    else 
+    {
       cfg->layouts= cfg_origin->layouts;
       cfg->header_enabled= cfg_origin->header_enabled;
       cfg->footer_enabled= cfg_origin->footer_enabled;
-      cfg->pattern_enabled= cfg_origin->pattern_enabled;
     }
   }
 
-  if (cfg_new->http_header_enabled == UNSET){
-    cfg->http_header= apr_pstrdup(p, cfg_origin->http_header);
-    cfg->http_header_enabled= cfg_origin->http_header_enabled;
-  } else if (isOn(cfg_new->http_header_enabled)){
-    cfg->http_header= apr_pstrdup(p, cfg_new->http_header);
-    cfg->http_header_enabled= cfg_new->http_header_enabled;
-  } else {
-    cfg->http_header_enabled= OFF;
-  }
-
-  /* This is pretty simple */
-  cfg->types= cfg_new->types;
-
-  if (cfg_origin->uris_ignore) {
-    if (cfg_new->uris_ignore) {
+  if (cfg_origin->uris_ignore) 
+  {
+    if (cfg_new->uris_ignore) 
       cfg->uris_ignore= apr_table_overlay(p, cfg_new->uris_ignore, cfg_origin->uris_ignore);
-    } else {
+    else 
       cfg->uris_ignore= cfg_origin->uris_ignore;
-    }
-  } else {
+  } 
+  else 
     cfg->uris_ignore= cfg_new->uris_ignore;
-  }
 
-  if (cfg_origin->uris_ignore_header) {
-    if (cfg_new->uris_ignore_header) {
+  if (cfg_origin->uris_ignore_header) 
+  {
+    if (cfg_new->uris_ignore_header) 
       cfg->uris_ignore_header= apr_table_overlay(p, cfg_new->uris_ignore_header, cfg_origin->uris_ignore_header);
-    } else {
+    else
       cfg->uris_ignore_header= cfg_origin->uris_ignore_header;
-    }
-  } else {
+  } 
+  else
     cfg->uris_ignore_header= cfg_new->uris_ignore_header;
-  }
 
-  if (cfg_origin->uris_ignore_http_header) {
-    if (cfg_new->uris_ignore_http_header) {
-      cfg->uris_ignore_http_header= apr_table_overlay(p, cfg_new->uris_ignore_http_header, cfg_origin->uris_ignore_http_header);
-    } else {
-      cfg->uris_ignore_http_header= cfg_origin->uris_ignore_http_header;
-    }
-  } else {
-    cfg->uris_ignore_http_header= cfg_new->uris_ignore_http_header;
-  }
-
-  if (cfg_origin->uris_ignore_footer) {
-    if (cfg_new->uris_ignore_footer) {
+  if (cfg_origin->uris_ignore_footer) 
+  {
+    if (cfg_new->uris_ignore_footer)
       cfg->uris_ignore_footer= apr_table_overlay(p, cfg_new->uris_ignore_footer, cfg_origin->uris_ignore_footer);
-    } else {
+    else
       cfg->uris_ignore_footer= cfg_origin->uris_ignore_footer;
-    }
-  } else {
+  }
+  else
     cfg->uris_ignore_footer= cfg_new->uris_ignore_footer;
-  }
 
-  if (cfg_origin->tag_ignore) {
-    if (cfg_new->tag_ignore) {
+  if (cfg_origin->tag_ignore) 
+  {
+    if (cfg_new->tag_ignore)
       cfg->tag_ignore= apr_table_overlay(p, cfg_new->tag_ignore, cfg_origin->tag_ignore);
-    } else {
+    else
       cfg->tag_ignore= cfg_origin->tag_ignore;
-    }
-  } else {
+  } 
+  else
     cfg->tag_ignore= cfg_new->tag_ignore;
-  }
 
-  if (cfg_origin->tag_ignore_footer) {
-    if (cfg_new->tag_ignore_footer) {
+  if (cfg_origin->tag_ignore_footer) 
+  {
+    if (cfg_new->tag_ignore_footer)
       cfg->tag_ignore_footer= apr_table_overlay(p, cfg_new->tag_ignore_footer, cfg_origin->tag_ignore_footer);
-    } else {
+    else
       cfg->tag_ignore_footer= cfg_origin->tag_ignore_footer;
-    }
-  } else {
+  } 
+  else
     cfg->tag_ignore_footer= cfg_new->tag_ignore_footer;
-  }
 
-  if (cfg_origin->tag_ignore_header) {
-    if (cfg_new->tag_ignore_header) {
+  if (cfg_origin->tag_ignore_header) 
+  {
+    if (cfg_new->tag_ignore_header)
       cfg->tag_ignore_header= apr_table_overlay(p, cfg_new->tag_ignore_header, cfg_origin->tag_ignore_header);
-    } else {
+    else
       cfg->tag_ignore_header= cfg_origin->tag_ignore_header;
-    }
-  } else {
+  } 
+  else
     cfg->tag_ignore_header= cfg_new->tag_ignore_header;
-  }
 
   return (void *) cfg;
 }
@@ -252,32 +187,39 @@ static apr_status_t layout_filter(ap_filter_t *f, apr_bucket_brigade *b)
 
   if (r->main) 
   {
+    ap_remove_output_filter(f);
     return ap_pass_brigade(f->next, b);
   }
 
-  apr_table_setn(r->headers_out, "X-Powered-By", "ModLayout/"VERSION);
   cfg= ap_get_module_config(r->per_dir_config, &layout_module);
 
+  WATCHPOINT_STRING(r->content_type);
+  WATCHPOINT_STRING(r->handler);
+
+  apr_table_setn(r->headers_out, "X-Powered-By", "ModLayout/"VERSION);
+
+  /* If no layouts were specified, we skip */
+  if (cfg->layouts == NULL) 
+  {
+    ap_remove_output_filter(f);
+    return ap_pass_brigade(f->next, b);
+  }
 
   /* Now lets look at the ignore logic */
   /* This is where we finally decide what is going to happen */
-  if (cfg->uris_ignore) 
+  if (cfg->uris_ignore && table_find(cfg->uris_ignore, r->uri))
   {
-    if (table_find(cfg->uris_ignore, r->uri)) 
-      return ap_pass_brigade(f->next, b);
+    ap_remove_output_filter(f);
+    return ap_pass_brigade(f->next, b);
   }
 
-
   info= create_layout_request(r, cfg);
 
-
-#ifdef DEBUG
-  if (isOff(info->header)  && isOff(info->footer) && isOff(info->http_header)) 
+  if (isOff(info->header)  && isOff(info->footer))
   {
+    ap_remove_output_filter(f);
     return ap_pass_brigade(f->next, b);
   }
-  printf("Fixup Header:%d: Footer:%d: HTTPHeader:%d:\n", info->header, info->footer, info->http_header);
-#endif
 
   if (ctx == NULL) 
   {
@@ -332,23 +274,12 @@ static apr_status_t layout_filter(ap_filter_t *f, apr_bucket_brigade *b)
       ctx->output= apr_psprintf(r->pool,"%s%.*s", ctx->output, (int)len, str);
     else
       ctx->output= apr_pstrndup(r->pool, str, len);
-  } 
-
+  }
 
   apr_brigade_destroy(b);
   return APR_SUCCESS;
 }
 
-static const char * add_http_header(cmd_parms * cmd, void *mconfig, const char *uri) 
-{
-  layout_conf *cfg= (layout_conf *) mconfig;
-
-  cfg->http_header= apr_pstrdup(cmd->pool, uri);
-  cfg->http_header_enabled= ON;
-
-  return NULL;
-}
-
 static const char * add_layout_pattern(cmd_parms * cmd, void *mconfig, const char *pattern, const char *layout, const char *mode) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
@@ -367,7 +298,7 @@ static const char * add_layout_pattern(cmd_parms * cmd, void *mconfig, const cha
   } 
   else if (stat(layout, &sbuf) == 0)
   {
-    unless((temp= layout_add_file(cmd, layout))) 
+    if ((temp= layout_add_file(cmd, layout)) == 0) 
       return NULL;
     directive->comment= apr_pstrdup (cmd->pool, layout);
     directive->string= apr_pstrdup (cmd->pool, temp);
@@ -378,37 +309,34 @@ static const char * add_layout_pattern(cmd_parms * cmd, void *mconfig, const cha
     directive->comment= apr_pstrdup (cmd->pool, layout);
     directive->string= apr_pstrdup (cmd->pool, layout);
     directive->type= 0;
-    if (cfg->cache_needed == UNSET)
-      cfg->cache_needed= ON;
   }
   directive->pattern= apr_pstrdup (cmd->pool, pattern);
 
-  unless(cfg->layouts) 
+  if (cfg->layouts == 0) 
     cfg->layouts= apr_array_make (cmd->pool, 1, sizeof (layout_string *));
 
-  unless(strcasecmp(cmd->cmd->name, "LayoutHeader")) 
+  if (strcasecmp(cmd->cmd->name, "LayoutHeader") == 0) 
   {
     cfg->header_enabled= ON;
     directive->kind= HEADER;
   } 
-  else unless(strcasecmp(cmd->cmd->name, "LayoutFooter")) 
+  else if (strcasecmp(cmd->cmd->name, "LayoutFooter") == 0) 
   {
     cfg->footer_enabled= ON;
     directive->kind= FOOTER;
   } 
   else 
   {
-    cfg->pattern_enabled= ON;
     directive->kind= LAYOUT;
   }
 
   if (mode) 
   {
-    unless(strcasecmp(mode, "append")) 
+    if (strcasecmp(mode, "append") == 0) 
       directive->append= APPEND;
-    else unless(strcasecmp(mode, "prepend")) 
+    else if (strcasecmp(mode, "prepend") == 0) 
       directive->append= PREPEND;
-    else unless(strcasecmp(mode, "replace")) 
+    else if(strcasecmp(mode, "replace") == 0) 
       directive->append= REPLACE;
     else 
     {
@@ -428,9 +356,9 @@ static const char * add_layout_pattern(cmd_parms * cmd, void *mconfig, const cha
 static const char * add_layout(cmd_parms * cmd, void *mconfig, const char *layout) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
-  unless(strcasecmp(cmd->cmd->name, "LayoutHeader")) 
+  if (strcasecmp(cmd->cmd->name, "LayoutHeader") == 0) 
     (void)add_layout_pattern(cmd, mconfig, (char *)cfg->begin_tag, layout, "append");
-  else unless(strcasecmp(cmd->cmd->name, "LayoutFooter"))
+  else if (strcasecmp(cmd->cmd->name, "LayoutFooter") == 0)
     (void)add_layout_pattern(cmd, mconfig, (char *)cfg->end_tag, layout, "prepend");
   return NULL;
 }
@@ -439,7 +367,7 @@ static const char * add_layout(cmd_parms * cmd, void *mconfig, const char *layou
 static const char * ignore_uri(cmd_parms * cmd, void *mconfig, const char *uri) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
-  unless(cfg->uris_ignore)
+  if (cfg->uris_ignore == 0)
     cfg->uris_ignore= apr_table_make(cmd->pool, 1);
 
   apr_table_setn(cfg->uris_ignore, uri, "1");
@@ -450,7 +378,7 @@ static const char * ignore_uri(cmd_parms * cmd, void *mconfig, const char *uri)
 static const char * ignore_header_uri(cmd_parms * cmd, void *mconfig, const char *uri) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
-  unless(cfg->uris_ignore_header)
+  if (cfg->uris_ignore_header == 0)
     cfg->uris_ignore_header= apr_table_make(cmd->pool, 1);
 
   apr_table_setn(cfg->uris_ignore_header, uri, "1");
@@ -458,21 +386,10 @@ static const char * ignore_header_uri(cmd_parms * cmd, void *mconfig, const char
   return NULL;
 }
 
-static const char * ignore_http_header_uri(cmd_parms * cmd, void *mconfig, const char *uri) 
-{
-  layout_conf *cfg= (layout_conf *) mconfig;
-  unless(cfg->uris_ignore_http_header)
-    cfg->uris_ignore_http_header= apr_table_make(cmd->pool, 1);
-
-  apr_table_setn(cfg->uris_ignore_http_header, uri, "1");
-
-  return NULL;
-}
-
 static const char * ignore_footer_uri(cmd_parms * cmd, void *mconfig, const char *uri) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
-  unless(cfg->uris_ignore_footer)
+  if (cfg->uris_ignore_footer == 0)
     cfg->uris_ignore_footer= apr_table_make(cmd->pool, 1);
 
   apr_table_setn(cfg->uris_ignore_footer, uri, "1");
@@ -480,18 +397,10 @@ static const char * ignore_footer_uri(cmd_parms * cmd, void *mconfig, const char
   return NULL;
 }
 
-static const char * add_type(cmd_parms * cmd, void *mconfig, const char *type) 
-{
-  layout_conf *cfg= (layout_conf *) mconfig;
-  apr_table_setn(cfg->types, type, "1");
-
-  return NULL;
-}
-
 static const char * tag_ignore_add(cmd_parms * cmd, void *mconfig, const char *type) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
-  unless(cfg->tag_ignore)
+  if (cfg->tag_ignore == 0)
     cfg->tag_ignore= apr_table_make(cmd->pool, 1);
 
   apr_table_setn(cfg->tag_ignore, type, "1");
@@ -502,7 +411,7 @@ static const char * tag_ignore_add(cmd_parms * cmd, void *mconfig, const char *t
 static const char * tag_ignore_footer_add(cmd_parms * cmd, void *mconfig, const char *type) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
-  unless(cfg->tag_ignore_footer)
+  if (cfg->tag_ignore_footer == 0)
     cfg->tag_ignore_footer= apr_table_make(cmd->pool, 1);
 
   apr_table_setn(cfg->tag_ignore_footer, type, "1");
@@ -513,7 +422,7 @@ static const char * tag_ignore_footer_add(cmd_parms * cmd, void *mconfig, const
 static const char * tag_ignore_header_add(cmd_parms * cmd, void *mconfig, const char *type) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
-  unless(cfg->tag_ignore_header)
+  if (cfg->tag_ignore_header == 0)
     cfg->tag_ignore_header= apr_table_make(cmd->pool, 1);
 
   apr_table_setn(cfg->tag_ignore_header, type, "1");
@@ -521,16 +430,7 @@ static const char * tag_ignore_header_add(cmd_parms * cmd, void *mconfig, const
   return NULL;
 }
 
-static const char * merge_add(cmd_parms * cmd, void *mconfig, int flag) 
-{
-  layout_conf *cfg= (layout_conf *) mconfig;
-
-  cfg->merge= flag;
-  cfg->display_origin= ON;
-
-  return NULL;
-}
-
+#ifdef NOT_USED
 static const char * footer_off(cmd_parms * cmd, void *mconfig) 
 {
   layout_conf *cfg= (layout_conf *) mconfig;
@@ -546,15 +446,7 @@ static const char * header_off(cmd_parms * cmd, void *mconfig)
 
   return NULL;
 }
-
-static const char * http_header_off(cmd_parms * cmd, void *mconfig) 
-{
-  layout_conf *cfg= (layout_conf *) mconfig;
-  cfg->http_header= NULL;
-  cfg->http_header_enabled= OFF;
-
-  return NULL;
-}
+#endif
 
 static const char * append_layouts(cmd_parms * cmd, void *mconfig, int flag) 
 {
@@ -565,9 +457,21 @@ static const char * append_layouts(cmd_parms * cmd, void *mconfig, int flag)
   return NULL;
 }
 
+/* Just here for debugging purposes */
+static int layout_fixup(request_rec *r)
+{
+  WATCHPOINT_STRING(r->content_type);
+  WATCHPOINT_STRING(r->handler);
+
+  return DECLINED;
+}
+
 static void layout_register_hooks(apr_pool_t *p) 
 {
   ap_register_output_filter("LAYOUT", layout_filter, NULL, AP_FTYPE_CONTENT_SET);
+#ifdef HAVE_DEBUG
+  ap_hook_fixups(layout_fixup, NULL, NULL, APR_HOOK_LAST);
+#endif
 }
 
 static const command_rec layout_cmds[]= {
@@ -575,23 +479,15 @@ static const command_rec layout_cmds[]= {
   AP_INIT_TAKE1("LayoutHeader", add_layout, NULL, OR_ALL, LayoutHeader),
   AP_INIT_TAKE1("LayoutFooter", add_layout, NULL, OR_ALL, LayoutFooter),
   AP_INIT_FLAG("LayoutAppend", append_layouts, NULL, OR_ALL, LayoutAppend),
-  AP_INIT_FLAG("LayoutAppendHeader", ap_set_flag_slot, (void *) APR_OFFSETOF(layout_conf, append_header), OR_ALL, LayoutHeaderAppend),
-  AP_INIT_FLAG("LayoutAppendFooter", ap_set_flag_slot, (void *) APR_OFFSETOF(layout_conf, append_header), OR_ALL, LayoutFooterAppend),
   AP_INIT_TAKE1("LayoutIgnoreURI", ignore_uri, NULL, OR_ALL, LayoutIgnoreURI),
   AP_INIT_TAKE1("LayoutIgnoreHeaderURI", ignore_header_uri, NULL, OR_ALL, LayoutIgnoreHeaderURI),
-  AP_INIT_TAKE1("LayoutIgnoreHTTPHeaderURI", ignore_http_header_uri, NULL, OR_ALL, LayoutIgnoreHTTPHeaderURI),
   AP_INIT_TAKE1("LayoutIgnoreFooterURI", ignore_footer_uri, NULL, OR_ALL, LayoutIgnoreFooterURI),
   AP_INIT_FLAG("LayoutComment", ap_set_flag_slot, (void *) APR_OFFSETOF(layout_conf, comment), OR_ALL, LayoutComment),
   AP_INIT_FLAG("LayoutDisplayOriginal", ap_set_flag_slot, (void *) APR_OFFSETOF(layout_conf, display_origin), OR_ALL, LayoutDisplayOriginal),
   AP_INIT_TAKE1("LayoutTimeFormat", ap_set_string_slot, (void *) APR_OFFSETOF(layout_conf, time_format), OR_ALL, LayoutTimeFormat),
-  AP_INIT_TAKE1("LayoutHTTPHeader", add_http_header, NULL, OR_ALL, LayoutHTTPHeader),
   AP_INIT_TAKE1("LayoutIgnoreTag", tag_ignore_add, NULL, OR_ALL, LayoutIgnoreTag),
   AP_INIT_TAKE1("LayoutIgnoreTagFooter", tag_ignore_footer_add, NULL, OR_ALL, LayoutIgnoreTagFooter),
   AP_INIT_TAKE1("LayoutIgnoreTagHeader", tag_ignore_header_add, NULL, OR_ALL, LayoutIgnoreTagHeader),
-  AP_INIT_FLAG("LayoutPostAsync", ap_set_flag_slot, (void *) APR_OFFSETOF(layout_conf, async_post), OR_ALL, LayoutPostAsync),
-  AP_INIT_TAKE1("LayoutBeginTag", ap_set_string_slot, (void *) APR_OFFSETOF(layout_conf, begin_tag), OR_ALL, LayoutMergeBeginTag),
-  AP_INIT_TAKE1("LayoutEndTag", ap_set_string_slot, (void *) APR_OFFSETOF(layout_conf, end_tag), OR_ALL, LayoutMergeEndTag),
-  AP_INIT_FLAG("LayoutReplaceTags", ap_set_flag_slot, (void *) APR_OFFSETOF(layout_conf, replace_tags), OR_ALL, LayoutReplaceTags),
   AP_INIT_FLAG("LayoutNotes", ap_set_flag_slot, (void *) APR_OFFSETOF(layout_conf, notes), OR_ALL, LayoutNotes),
   {NULL}
 };
@@ -606,4 +502,3 @@ module AP_MODULE_DECLARE_DATA layout_module= {
   layout_cmds,           /* table of config file commands       */
   layout_register_hooks  /* register hooks                      */
 };
-
