@@ -30,8 +30,6 @@
 #define ON (1)
 #define isOff(a) ((a == ON) ? 0 : 1 )
 #define isOn(a) ((a == ON) ? 1 : 0 )
-/* Yeah, I write perl, got a problem with that? */
-#define unless(a) if (!(a))
 
 /* layout states */
 #define LAYOUT (0)
@@ -45,11 +43,28 @@
 #define REPLACE (2)
 #define PREPEND (3)
 
-#define WATCHPOINT printf("WATCHPOINT %s %d\n", __FILE__, __LINE__);
-#define AWATCHPOINT ap_rprintf(r, "WATCHPOINT %s %d\n", __FILE__, __LINE__);
+#ifndef __WATCHPOINT_H__
+#define __WATCHPOINT_H__
+/* Some personal debugging functions */
+#ifdef HAVE_DEBUG
+#define WATCHPOINT printf("\nWATCHPOINT %s:%d (%s)\n", __FILE__, __LINE__,__func__);fflush(stdout);
+#define WATCHPOINT_STRING(A) printf("\nWATCHPOINT %s:%d (%s) %s\n", __FILE__, __LINE__,__func__,A);fflush(stdout);
+#define WATCHPOINT_STRING_LENGTH(A,B) printf("\nWATCHPOINT %s:%d (%s) %.*s\n", __FILE__, __LINE__,__func__,(int)B,A);fflush(stdout);
+#define WATCHPOINT_NUMBER(A) printf("\nWATCHPOINT %s:%d (%s) %zu\n", __FILE__, __LINE__,__func__,(size_t)(A));fflush(stdout);
+#define WATCHPOINT_ERRNO(A) printf("\nWATCHPOINT %s:%d (%s) %s\n", __FILE__, __LINE__,__func__, strerror(A));A= 0;fflush(stdout);
+#define WATCHPOINT_ASSERT(A) assert((A));
+#else
+#define WATCHPOINT
+#define WATCHPOINT_STRING(A)
+#define WATCHPOINT_STRING_LENGTH(A,B)
+#define WATCHPOINT_NUMBER(A)
+#define WATCHPOINT_ERRNO(A)
+#define WATCHPOINT_ASSERT(A)
+#endif
+
+#endif /* __WATCHPOINT_H__ */
 #define LAYOUT_EXPORT(type)    type
 
-#define LAYOUT_CACHE "/tmp"
 #define LAYOUT_BEGINTAG "<body*>"
 #define LAYOUT_ENDTAG "</body>"
 #define LAYOUT_TIMEFORMAT "%A, %d-%b-%Y %H:%M:%S %Z"
@@ -69,14 +84,11 @@ typedef struct {
 } mmap_data;
 
 typedef struct {
-  int http_header;
   int header;
   int footer;
   int length;
-  int pid;
   int http;
   int origin;
-  int merge;
   const char *type;
   const char *mime;
   ap_filter_t *f; 
@@ -84,40 +96,27 @@ typedef struct {
 } layout_request;
 
 typedef struct {
-  int proxy;
-  int glob;
   apr_array_header_t *layouts;
   int header_enabled;
   int footer_enabled;
-  int pattern_enabled;
   int display_origin;
   apr_table_t *override;
   apr_table_t *override_uri;
-  int async_post;
-  const char *async_cache;
-  int http_header_enabled;
   int comment;
   /* These next three variables change with each request */
-  char *http_header;
   const char *time_format;
-  apr_table_t *types;
   apr_table_t *uris_ignore;
   apr_table_t *uris_ignore_header;
-  apr_table_t *uris_ignore_http_header;
   apr_table_t *uris_ignore_footer;
   apr_table_t *tag_ignore;
   apr_table_t *tag_ignore_footer;
   apr_table_t *tag_ignore_header;
   int append_header;
   int append_footer;
-  int cache_needed;
-  int merge;
   int notes;
-  int replace_tags;
   const char *begin_tag;
   const char *end_tag;
   const char *dir;
-  int layout_html_handler;
 } layout_conf;
 
 typedef struct layout_filter_struct {
