@@ -4,17 +4,8 @@
  **  
  **  Copyright 2007 Brian Aker brian@tangent.org
  **  
- **  Licensed under the Apache License, Version 2.0 (the "License");
- **  you may not use this file except in compliance with the License.
- **  You may obtain a copy of the License at
+ ** Please see "LICENSE" file that was included in the distribution.
  **  
- **  http://www.apache.org/licenses/LICENSE-2.0
- **  
- **  Unless required by applicable law or agreed to in writing, software
- **  distributed under the License is distributed on an "AS IS" BASIS,
- **  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- **  See the License for the specific language governing permissions and
- **  limitations under the License.
 */
 
 #include "mod_layout.h"
@@ -61,12 +52,13 @@ LAYOUT_EXPORT(int) check_type(layout_request *request)
   if (request->http == ORIGIN)
     return 0;
 
-  unless(request->type)
+  if (request->type == 0)
     return 0;
-  unless(strcmp(request->type, "text/plain"))
+  if (strcmp(request->type, "text/plain") == 0)
     return 1;
-  unless(strcmp(request->type, "text/html"))
+  if (strcmp(request->type, "text/html") == 0)
     return 1;
+
   return 0;
 }
 
@@ -77,13 +69,10 @@ LAYOUT_EXPORT(layout_request *) create_layout_request(request_rec *r, layout_con
   info= apr_pcalloc(r->pool, sizeof(layout_request));
 
   info->origin= cfg->display_origin;
-  info->merge= cfg->merge;
-  info->http_header= OFF;
   info->header= OFF;
   info->footer= OFF;
   if ((content_length= apr_table_get(r->headers_in, "Content-Length")))
     info->length= (content_length ? atoi(content_length) : 0);
-  info->pid= getpid();
   info->type= NULL;
   info->http= LAYOUT;
 
@@ -101,16 +90,6 @@ LAYOUT_EXPORT(layout_request *) create_layout_request(request_rec *r, layout_con
     }
   }
 
-  if (isOn(cfg->http_header_enabled)) 
-  {
-    info->http_header= ON;
-    if (cfg->uris_ignore_http_header) 
-    {
-      if (table_find(cfg->uris_ignore_http_header, r->uri))
-        info->http_header= OFF;
-    }
-  }
-
   if (isOn(cfg->footer_enabled)) 
   {
     info->footer= ON;
@@ -166,7 +145,7 @@ LAYOUT_EXPORT(void) table_cat(apr_table_t *src, apr_table_t *dest, char *string)
   {
     for (x= 0; x < hdrs_arr->nelts; ++x) 
     {
-      unless(strcasecmp(string,elts[x].key)) 
+      if (strcasecmp(string,elts[x].key) == 0) 
         apr_table_add(dest, elts[x].key, elts[x].val);
     }
   } 
@@ -222,17 +201,19 @@ LAYOUT_EXPORT(int) string_search(request_rec *r, const char *string, const char
       substring= apr_pstrndup(r->pool, sub_temp , end + 1);
       lower= apr_pstrdup(r->pool, substring);
       ap_str_tolower(lower);
-      unless(apr_fnmatch(delim, lower, APR_FNM_CASE_BLIND)) {
-        if (flag) {
+      if (apr_fnmatch(delim, lower, APR_FNM_CASE_BLIND) == 0) 
+      {
+        if (flag)
           complete_position += position;
-        } else {
+        else 
           complete_position += position + end + 1;
-        }
+
         return complete_position;
       }
-    } else {
+    } 
+    else
       return -1;
-    }
+
     temp += end + 1;
     complete_position += end + 1;
   }
@@ -240,7 +221,8 @@ LAYOUT_EXPORT(int) string_search(request_rec *r, const char *string, const char
   return -1;
 }
 
-LAYOUT_EXPORT(int) parser_put(request_rec *r, layout_conf *cfg, layout_request *info, const char *string, int init_pos) {
+LAYOUT_EXPORT(int) parser_put(request_rec *r, layout_conf *cfg, layout_request *info, const char *string, int init_pos) 
+{
   char *temp= NULL;
   char *sub_temp= NULL;
   char *lower= NULL;
@@ -254,7 +236,11 @@ LAYOUT_EXPORT(int) parser_put(request_rec *r, layout_conf *cfg, layout_request *
   int run= 0;
   layout_string **layouts;
 
-  layouts= (layout_string **) cfg->layouts->elts;
+  if (cfg->layouts != NULL)
+    layouts= (layout_string **) cfg->layouts->elts;
+  else 
+    layouts= NULL;
+
 
   if (string == NULL) 
     return -1;
@@ -265,42 +251,56 @@ LAYOUT_EXPORT(int) parser_put(request_rec *r, layout_conf *cfg, layout_request *
   complete_position= init_pos;
 
   x= init_pos;
-  while ( x < length ) {
-    if ( string[x] == '<') {
+  while ( x < length ) 
+  {
+    if (string[x] == '<') 
+    {
       sub_temp= (char *)string + x;
-      if ((end= ap_ind(sub_temp, '>')) != -1) { 
+
+      if ((end= ap_ind(sub_temp, '>')) != -1 && layouts)
+      {
         substring= apr_pstrndup(r->pool, sub_temp , end + 1);
         lower= apr_pstrdup(r->pool, substring);
         ap_str_tolower(lower);
 #ifdef DEBUG
         printf("MATCH: %s (%d)\n", lower, cfg->layouts->nelts);
 #endif
-        for (j= 0; j < cfg->layouts->nelts; j++) {
+        for (j= 0; j < cfg->layouts->nelts; j++) 
+        {
 #ifdef DEBUG
           printf("\tWITH: %s\n", layouts[j]->pattern);
 #endif
           /* The next few lines should be reduced */
           run= 1;
-          if (layouts[j]->kind == HEADER && !info->header) {
+          if (layouts[j]->kind == HEADER && !info->header)
             run= 0;
-          }
-          if (layouts[j]->kind == FOOTER && !info->footer) {
+          if (layouts[j]->kind == FOOTER && !info->footer)
             run= 0;
-          }
-          if (run) {
-            unless(apr_fnmatch(layouts[j]->pattern, lower, APR_FNM_CASE_BLIND)) {
-              if (layouts[j]->append == APPEND) {
+
+          if (run) 
+          {
+            if (apr_fnmatch(layouts[j]->pattern, lower, APR_FNM_CASE_BLIND) == 0)
+            {
+              if (layouts[j]->append == APPEND) 
+              {
                 ap_fputs(info->f, info->b, substring);
                 layout_print(r, cfg, info, j);
+
                 if (isOn(cfg->notes))
                   update_info(r->notes, info);
-              } else if (layouts[j]->append == PREPEND) {
+              } 
+              else if (layouts[j]->append == PREPEND)
+              {
                 layout_print(r, cfg, info, j);
+
                 if (isOn(cfg->notes))
                   update_info(r->notes, info);
                 ap_fputs(info->f, info->b, substring);
-              } else { /* We replace! */
+              } 
+              else 
+              { /* We replace! */
                 layout_print(r, cfg, info, j);
+
                 if (isOn(cfg->notes))
                   update_info(r->notes, info);
               }
@@ -308,17 +308,21 @@ LAYOUT_EXPORT(int) parser_put(request_rec *r, layout_conf *cfg, layout_request *
             }
           }
         }
-        unless (match)  {
+        if (match == 0)
           ap_fputs(info->f, info->b, substring);
-        }
+
         match= 0;
         x += strlen(substring);
-      } else {
+      }
+      else
+      {
         /* If we never match just write out the substring and keep going */
         ap_fputc(info->f, info->b, string[x]);
         x++;
       }
-    } else {
+    } 
+    else
+    {
       ap_fputc(info->f, info->b, string[x]);
       x++;
     }
@@ -327,16 +331,16 @@ LAYOUT_EXPORT(int) parser_put(request_rec *r, layout_conf *cfg, layout_request *
   return -1;
 }
 
-LAYOUT_EXPORT(int) find_headers(request_rec *r, char *body) {
+LAYOUT_EXPORT(int) find_headers(request_rec *r, char *body)
+{
   int position= 0;
   char *temp= NULL;
-  int end= 0;
+  unsigned int end= 0;
 
   temp= body;
 
-  if (body==NULL) { 
+  if (body == NULL)
     return -1;
-  }
 
   while ((position= ap_ind(temp, '\n')) != -1) 
   {
@@ -362,6 +366,7 @@ int check_table(const char *a)
 {
   if (a == NULL) 
     return 0;
+
   if ('1' == a[0])
     return 1;
 
@@ -375,20 +380,21 @@ LAYOUT_EXPORT(int) table_find(const apr_table_t *t, const char *key)
 {
   const apr_array_header_t *hdrs_arr= NULL;
   const apr_table_entry_t *elts= NULL;
-  int i= 0;
+  unsigned int x= 0;
 
   if (t == NULL)
     return 0;
+
   hdrs_arr= apr_table_elts(t);
   elts= (const apr_table_entry_t *) hdrs_arr->elts;
 
   if (key == NULL)
     return 0;
 
-  for (i= 0; i < hdrs_arr->nelts; ++i) 
+  for (x= 0; x < hdrs_arr->nelts; ++x) 
   {
-    if (!apr_fnmatch(elts[i].key, key, APR_FNM_CASE_BLIND))
-      if (check_table(elts[i].val))
+    if (!apr_fnmatch(elts[x].key, key, APR_FNM_CASE_BLIND))
+      if (check_table(elts[x].val))
         return 1;
   }
 
@@ -422,10 +428,6 @@ LAYOUT_EXPORT(void) update_info(const apr_table_t *t, layout_request *info)
         info->header= OFF;
       else if (!apr_fnmatch(elts[i].val, "headeron", APR_FNM_CASE_BLIND))
         info->header= ON;
-      else if (!apr_fnmatch(elts[i].val, "mergeoff", APR_FNM_CASE_BLIND))
-        info->merge= OFF;
-      else if (!apr_fnmatch(elts[i].val, "mergeon", APR_FNM_CASE_BLIND))
-        info->merge= ON;
     }
   }
 }
@@ -441,36 +443,22 @@ LAYOUT_EXPORT(int) is_ignored(request_rec *r, layout_conf *cfg, layout_request *
       return 1;
     }
   }
+
   if (cfg->tag_ignore_footer) 
   {
     if (table_search(r, cfg->tag_ignore_footer, body))
       info->footer= OFF;
   }
+
   if (cfg->tag_ignore_header) 
   {
     if (table_search(r, cfg->tag_ignore_header, body))
       info->header= OFF;
   }
+
   return 0;
 }
 
-LAYOUT_EXPORT(void) layout_headers(request_rec *r, layout_conf *cfg, layout_request *info) 
-{
-  int status= LAYOUT;
-#ifdef old_code
-  layout_string **current_header;
-#endif
-
-  /* HTTP always overrule all headers */
-  if (info->http_header) 
-  {
-    info->http= HTTP;
-    return;
-  }
-
-  info->http= status;
-}
-
 LAYOUT_EXPORT(int) call_container(request_rec *r, const char *uri, layout_conf *cfg, layout_request *info, int assbackwards) 
 {
   int status= OK;
@@ -487,8 +475,10 @@ LAYOUT_EXPORT(int) call_container(request_rec *r, const char *uri, layout_conf *
   apr_table_setn(subr->subprocess_env, "LAYOUT_PATH_INFO", r->path_info);
   apr_table_setn(subr->subprocess_env, "LAYOUT_QUERY_STRING", r->args);
   apr_table_setn(subr->subprocess_env, "LAYOUT_FILENAME", r->filename);
-  //	apr_table_setn(subr->subprocess_env, "LAYOUT_LAST_MODIFIED",
-  //			apr_ht_time(r->pool, r->finfo.st_mtime, cfg->time_format, 0));
+#ifdef NOT_USED
+  apr_table_setn(subr->subprocess_env, "LAYOUT_LAST_MODIFIED",
+  apr_ht_time(r->pool, r->finfo.st_mtime, cfg->time_format, 0));
+#endif
 #ifdef LAYOUT_FILEOWNER_NAME
   uidpasswd=getpwuid(r->finfo.st_uid);
   if (uidpasswd)
@@ -538,7 +528,7 @@ LAYOUT_EXPORT(char *) layout_add_file(cmd_parms *cmd, const char *file)
 
 LAYOUT_EXPORT(void) layout_kind(request_rec *r, layout_conf *cfg, layout_request *info, int kind) 
 {
-  int x= 0;
+  unsigned int x= 0;
   layout_string **layouts;
 
   layouts= (layout_string **) cfg->layouts->elts;
